/* *********************************************************************
 * This Original Work is copyright of 51 Degrees Mobile Experts Limited.
 * Copyright 2026 51 Degrees Mobile Experts Limited, Davidson House,
 * Forbury Square, Reading, Berkshire, United Kingdom RG1 3EU.
 *
 * This Original Work is licensed under the European Union Public Licence
 * (EUPL) v.1.2 and is subject to its terms as set out below.
 *
 * If a copy of the EUPL was not distributed with this file, You can obtain
 * one at https://opensource.org/licenses/EUPL-1.2.
 *
 * The 'Compatible Licences' set out in the Appendix to the EUPL (as may be
 * amended by the European Commission) shall be deemed incompatible for
 * the purposes of the Work and the provisions of the compatibility
 * clause in Article 5 of the EUPL shall not apply.
 *
 * If using the Work as, or as part of, a network application, by
 * including the attribution notice(s) required under Article 5 of the EUPL
 * in the end user terms of the application under an appropriate heading,
 * such notice(s) shall fulfill the requirements of that article.
 * ********************************************************************* */

#include "propertyValueType.h"

fiftyoneDegreesPropertyValueType
fiftyoneDegreesPropertyValueTypeGetUnderlyingType(
    fiftyoneDegreesPropertyValueType type) {
    switch (type) {
        case FIFTYONE_DEGREES_PROPERTY_VALUE_TYPE_WEIGHTED_STRING:
            return FIFTYONE_DEGREES_PROPERTY_VALUE_TYPE_STRING;
        case FIFTYONE_DEGREES_PROPERTY_VALUE_TYPE_WEIGHTED_INT:
            return FIFTYONE_DEGREES_PROPERTY_VALUE_TYPE_INTEGER;
        case FIFTYONE_DEGREES_PROPERTY_VALUE_TYPE_WEIGHTED_DOUBLE:
            return FIFTYONE_DEGREES_PROPERTY_VALUE_TYPE_DOUBLE;
        case FIFTYONE_DEGREES_PROPERTY_VALUE_TYPE_WEIGHTED_BOOL:
            return FIFTYONE_DEGREES_PROPERTY_VALUE_TYPE_BOOLEAN;
        case FIFTYONE_DEGREES_PROPERTY_VALUE_TYPE_WEIGHTED_SINGLE:
            return FIFTYONE_DEGREES_PROPERTY_VALUE_SINGLE_PRECISION_FLOAT;
        case FIFTYONE_DEGREES_PROPERTY_VALUE_TYPE_WEIGHTED_BYTE:
            return FIFTYONE_DEGREES_PROPERTY_VALUE_SINGLE_BYTE;
        case FIFTYONE_DEGREES_PROPERTY_VALUE_TYPE_WEIGHTED_IP_ADDRESS:
            return FIFTYONE_DEGREES_PROPERTY_VALUE_TYPE_IP_ADDRESS;
        case FIFTYONE_DEGREES_PROPERTY_VALUE_TYPE_WEIGHTED_WKB_R:
            return FIFTYONE_DEGREES_PROPERTY_VALUE_TYPE_WKB_R;
        default:
            return type;
    }
}
