/* *********************************************************************
 * This Original Work is copyright of 51 Degrees Mobile Experts Limited.
 * Copyright 2026 51 Degrees Mobile Experts Limited, Davidson House,
 * Forbury Square, Reading, Berkshire, United Kingdom RG1 3EU.
 *
 * This Original Work is licensed under the European Union Public Licence
 * (EUPL) v.1.2 and is subject to its terms as set out below.
 *
 * If a copy of the EUPL was not distributed with this file, You can obtain
 * one at https://opensource.org/licenses/EUPL-1.2.
 *
 * The 'Compatible Licences' set out in the Appendix to the EUPL (as may be
 * amended by the European Commission) shall be deemed incompatible for
 * the purposes of the Work and the provisions of the compatibility
 * clause in Article 5 of the EUPL shall not apply.
 *
 * If using the Work as, or as part of, a network application, by
 * including the attribution notice(s) required under Article 5 of the EUPL
 * in the end user terms of the application under an appropriate heading,
 * such notice(s) shall fulfill the requirements of that article.
 * ********************************************************************* */

#include "ConfigDeviceDetection.hpp"

using namespace FiftyoneDegrees::DeviceDetection;

ConfigDeviceDetection::ConfigDeviceDetection(
	fiftyoneDegreesConfigDeviceDetection *config) : 
	ConfigBase(&config->b) {
	this->config = config;
}

void ConfigDeviceDetection::setUpdateMatchedUserAgent(
	bool shouldUpdate) {
	config->updateMatchedUserAgent = shouldUpdate;
}

void ConfigDeviceDetection::setMaxMatchedUserAgentLength(
	int length) {
	config->maxMatchedUserAgentLength = length;
}

void ConfigDeviceDetection::setAllowUnmatched(bool allow) {
	config->allowUnmatched = allow;
}

void ConfigDeviceDetection::setProcessSpecialEvidence(
	bool process) {
	config->processSpecialEvidence = process;
}

bool ConfigDeviceDetection::getUpdateMatchedUserAgent() {
	return config->updateMatchedUserAgent;
}

int ConfigDeviceDetection::getMaxMatchedUserAgentLength() {
	return (int)config->maxMatchedUserAgentLength;
}

bool ConfigDeviceDetection::getAllowUnmatched() {
	return config->allowUnmatched;
}

bool ConfigDeviceDetection::getProcessSpecialEvidence() {
	return config->processSpecialEvidence;
}